------------------------------------------------------------------------------
--
--  Xilinx, Inc. 2004                 www.xilinx.com
--
------------------------------------------------------------------------------
--
--  File name :       clock.vhd
--
--  Description :     Clock for S3 demo board
--			Seg(0) = DP
--			Seg(1) = middle
--			Seg(2) = top left
--			Seg(3) = bottom left
--			Seg(4) = bottom
--			Seg(5) = bottom right
--			Seg(6) = top right
--			Seg(7) = top
--
--  Date - revision : 4th February 2004 - v 1.0
--
--  Author :          NJS
--
--  Contact : e-mail  hotline@xilinx.com
--            phone   + 1 800 255 7778
--
--  Disclaimer: LIMITED WARRANTY AND DISCLAMER. These designs are
--              provided to you "as is". Xilinx and its licensors make, and you
--              receive no warranties or conditions, express, implied,
--              statutory or otherwise, and Xilinx specifically disclaims any
--              implied warranties of merchantability, non-infringement, or
--              fitness for a particular purpose. Xilinx does not warrant that
--              the functions contained in these designs will meet your
--              requirements, or that the operation of these designs will be
--              uninterrupted or error free, or that defects in the Designs
--              will be corrected. Furthermore, Xilinx does not warrant or
--              make any representations regarding use or the results of the
--              use of the designs in terms of correctness, accuracy,
--              reliability, or otherwise.
--
--              LIMITATION OF LIABILITY. In no event will Xilinx or its
--              licensors be liable for any loss of data, lost profits, cost
--              or procurement of substitute goods or services, or for any
--              special, incidental, consequential, or indirect damages
--              arising from the use or operation of the designs or
--              accompanying documentation, however caused and on any theory
--              of liability. This limitation will apply even if Xilinx
--              has been advised of the possibility of such damage. This
--              limitation shall apply not-withstanding the failure of the
--              essential purpose of any limited remedies herein.
--
--  Copyright  2002 Xilinx, Inc.
--  All rights reserved
--
------------------------------------------------------------------------------
--
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_unsigned.all ;

--pragma translate_off
library unisim ;
use unisim.vcomponents.all ;
--pragma translate_on

entity clock is port (
	clk50in				: in std_logic ; 			-- 50 Mhz XTAL
     d6out                    : out std_logic ;
     c6out                    : out std_logic ;
	a2in                     : in std_logic_vector(7 downto 0);
	pb_in				: in std_logic_vector(3 downto 0);	-- 4 pushbutton inputs
	sw_in				: in std_logic_vector(7 downto 0);	-- 8 switch inputs
	digit_out			: out std_logic_vector(3 downto 0);	-- digit drivers
	led_out				: out std_logic_vector(7 downto 0);	-- 8 LEDs
	seg_out				: out std_logic_vector(7 downto 0));	-- segment drivers

end clock ;

architecture arch_clock of clock is

-- CMOS33 input buffer primitive
component ibuf_lvcmos33 port (i : in std_logic; o : out std_logic); end component;
-- CMOS33 clock input buffer primitive
component ibufg_lvcmos33 port(i : in std_logic; o : out std_logic); end component;
-- CMOS33 output buffer primitive
component obuf_lvcmos33 port(i : in std_logic; o : out std_logic); end component;
-- global buffer primitive
component bufg port(i : in std_logic; o : out std_logic); end component;

signal low 		: std_logic ;				-- logic '0'
signal high 		: std_logic ;				-- logic '1'
signal rst 		: std_logic ;				-- logic '1'
signal clk50int		: std_logic ;				-- 
signal clk50		: std_logic ;				-- 
signal pb 		: std_logic_vector(3 downto 0) ;	-- 
signal sw 		: std_logic_vector(7 downto 0) ;	-- 
signal led 		: std_logic_vector(7 downto 0) ;	-- 
signal digit 		: std_logic_vector(3 downto 0) ;	-- 
signal seg 		: std_logic_vector(7 downto 0) ;	-- 
signal pb4     : std_logic ;
signal onoff        : std_logic ;
signal d6           : std_logic ;
signal c6           : std_logic ;
signal a2           : std_logic_vector(7 downto 0) ;

begin

low 	<= '0' ;
high <= '1' ;
rst 	<= pb(0) ; 			
digit <= "1111" ;

clk50in_ibuf 	: ibufg_lvcmos33	port map(i => clk50in, 	o => clk50int );
rxclka_bufg 	: bufg 			port map(i => clk50int, o => clk50 ) ;
d6out_obuf     : obuf_lvcmos33     port map(i => d6, o => d6out);
c6out_obuf     : obuf_lvcmos33     port map(i => c6, o => c6out);

loop0 : for i in 0 to 3 generate
digit_obuf 	: obuf_lvcmos33  	port map(i => digit(i),	o => digit_out(i));
pb_ibuf 	: ibuf_lvcmos33  	port map(i => pb_in(i),	o => pb(i));
end generate ;

loop1 : for i in 0 to 7 generate
led_obuf 	: obuf_lvcmos33  	port map(i => led(i),	o => led_out(i));
digit_obuf 	: obuf_lvcmos33  	port map(i => seg(i),	o => seg_out(i));
sw_ibuf 	: ibuf_lvcmos33  	port map(i => sw_in(i),	o => sw(i));
a2_ibuf   : ibuf_lvcmos33     port map(i => a2in(i),   o => a2(i));
end generate ;


-- moved the led counter every second.
process (clk50, rst)
begin
if rst = '1' then
	d6 <= '0';
elsif clk50 = '1' then
	  d6 <= '1';
elsif clk50 = '0' then
	  d6 <= '0';
end if ;
end process ;

process (pb, rst)
begin
if rst = '1' then
     c6 <= '0';
elsif pb(1) = '1' then
     c6 <= '1';
else
     c6 <= '0';
end if;
end process;

process (a2, rst)
begin
if rst = '1' then
  led <= "00000000";
else
  led <= a2;
end if;
end process;

end arch_clock;
